@@ -17,6 +17,6 @@ class Command(BaseCommand):
 
         count = Message.objects.filter(visible=False).count()
 
-        print("Removing %s invisible %s... " % (
-                count, pluralize("message", count)))
+        print('Removing %s invisible %s... ' % (
+                count, pluralize('message', count)))
         Message.objects.cleanup()
